@@ -9,10 +9,7 @@ class OmegaGrammar(_core.CoreGrammar):
 	_parser = bootstrap.OmegaParser
 
 
-class BaseParser(_core.CoreParser):
-	# This class's parser definitions should be parsed as Omega source code.
-	__metaclass__ = OmegaGrammar
-
+class BaseParser(_core.CoreParser, metaclass=OmegaGrammar):
 	# Prevent any of our standard library functions from being picked as the
 	# default parsing rule.
 	_start = None
